\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{congrumi11}[2011/04/28 v1.3]

\LoadClass[12pt,a4paper]{amsart}
\RequirePackage[italian]{babel}
\RequirePackage[T1]{fontenc}
\RequirePackage{amssymb}
\RequirePackage{amscd}
\RequirePackage{graphicx}

% dimensione della pagina
\setlength\textwidth{15cm}
\setlength\@tempdima        {\paperwidth}
\addtolength\@tempdima      {-\textwidth}
\setlength\oddsidemargin    {.5\@tempdima}
\addtolength\oddsidemargin  {-1in}
\setlength\evensidemargin   \oddsidemargin
\setlength\textheight       {22.5cm}
\setlength\topmargin        {\z@}


% logo a inizio pagina
\def\logo{{}\hfill
	\begin{tabular}{c}\hline
	XX Congresso U.M.I.\\
	{\footnotesize Siena, 7--12 settembre 2015}\\
	\hline\end{tabular}\vspace*{15pt}\nopagebreak}
\AtBeginDocument{\thispagestyle{empty}\logo}

% Teoremi, definizioni ecc.
\newtheorem{teoremanum}{Teorema}
\newtheorem*{teorema}{Teorema}
\newtheorem{proposizionenum}[teoremanum]{Proposizione}
\newtheorem*{proposizione}{Proposizione}
\newtheorem{lemmanum}[teoremanum]{Lemma}
\newtheorem*{lemma}{Lemma}
\newtheorem{corollarionum}[teoremanum]{Corollario}
\newtheorem*{corollario}{Corollario}
\theoremstyle{definition}
\newtheorem{definizionenum}{Definizione}
\newtheorem*{definizione}{Definizione}
\let\dimostrazione\proof
\let\enddimostrazione\endproof

% comandi per l'intestazione

\newtoks\@toksintestazione
\newtoks\@tokstitolo
\newtoks\@toksemail
\newtoks\@tokssezione

% controllo se \afferenza e' preceduto da almeno un \autore o \autore*
\newif\if@utore
\@utorefalse
% controllo se c'e' esattamente un comando \autore*
\newif\if@utorestar
\@utorestarfalse
% controllo se c'e' un solo autore
\newif\ifun@utore
\un@utoretrue
% controllo se c'e' il comando \email
\newif\ifem@il
\em@ilfalse
% controllo che e' indicata la sezione
\newif\ifsezion@
\sezion@false

\def\titolo#1{\@tokstitolo={#1}}

\def\autore{\@ifstar{\@utorestar}{\@utore}}
\def\@utorestar#1{%
	\if@utorestar
	\ClassError{congrumi11}{Sono presenti due comandi \protect\autore*}{Il 
	comando \protect\autore* deve essere utilizzato una sola volta per 
	l'autore che presenta la comunicazione}
	\fi
	\if@utore
	\@toksintestazione=\expandafter{\the\@toksintestazione,\space}
	\else
	\@toksintestazione=\expandafter{\the\@toksintestazione
	\bgroup\itshape}
	\fi
	\@toksintestazione=\expandafter{\the\@toksintestazione\temp{#1}}
	\@utorestartrue
	\@utoretrue}
\def\@utore#1{%
	\if@utore
	\@toksintestazione=\expandafter{\the\@toksintestazione,\space}
	\else
	\@toksintestazione=\expandafter{\the\@toksintestazione
	\bgroup\itshape}
	\fi
	\@toksintestazione=\expandafter{\the\@toksintestazione#1}
	\@utoretrue
	\un@utorefalse}
\def\afferenza#1{%
	\if@utore
	\@toksintestazione=\expandafter{\the\@toksintestazione\egroup}
	\else
	\ClassError{congrumi11}{\noexpand\afferenza deve essere 
	immediatamente preceduto dalla indicazione di almeno un autore}{}
	\fi
	\@toksintestazione=\expandafter{\the\@toksintestazione
	\par{#1}\par\vspace*{4pt}}
	\@utorefalse}
\def\intestazione{%
	\if@utorestar
	\else
	\ClassError{congrumi11}{Manca il comando \protect\autore*}{Nel file 
	deve comparire il comando \protect\autore*, con argomento il nome 
	dell'autore che presenta la pubblicazione}
	\fi
	{\centering
	\textbf{\Large\the\@tokstitolo\\}\vspace*{3mm}
% se ci sono piu' autori quello che presenta la comunicazione viene 
% sottolineato
	\ifun@utore
	\let\temp\relax
	\else
	\let\temp\underline
	\fi
	\the\@toksintestazione\@thanks\vspace*{6pt}}
% \titolo \autore \autore* \afferenza devono precedere \intestazione
	\def\titolo{\ClassError{congrumi11}{Il comando \noexpand\titolo
	deve comparire prima di \noexpand\intestazione}{}}
	\def\@utorestar{\ClassError{congrumi11}{Il comando \protect\autore* 
	deve comparire prima di \noexpand\intestazione}{}}
	\def\@utore{\ClassError{congrumi11}{Il comando \noexpand\autore
	deve comparire prima di \noexpand\intestazione}{}}
	\def\afferenza{\ClassError{congrumi11}{Il comando \noexpand\afferenza
	deve comparire prima di \noexpand\intestazione}{}}}

\def\email#1{\@toksemail{E--mail: \texttt{#1}.}\em@iltrue}

\def\sezione#1{\@tokssezione{Sezione #1:\space\ifcase #1 
	\or Analisi non lineare e sistemi hamiltoniani.
	\or Equazioni alle derivate parziali.
	\or Equazioni differenziali ordinarie e sistemi dinamici.
	\or Calcolo delle variazioni e controllo.
	\or Analisi reale e diseguaglianze funzionali.
	\or Analisi armonica.
	\or Calcolo delle probabilit\`a e statistica matematica.
	\or Fisica matematica.
	\or Modelli matematici e applicazioni.
	\or Metodi numerici per le equazioni differenziali ordinarie.
	\or Teoria dell'approssimazione.
	\or Algebra lineare numerica e ottimizzazione.
	\or Metodi numerici per le equazioni alle derivate parziali.
	\or a) Algebra. b)Teoria di Lie
	\or Combinatoria.
	\or Topologia e geometria differenziale.
	\or Geometria complessa.
	\or Geometria algebrica.
	\or Logica matematica.
	\or Teoria dei numeri.
	\or Storia della matematica.
	\or Didattica della matematica.
	\or Divulgazione della matematica.
	\fi}
	\sezion@true}

\AtEndDocument{%
	\def\@thefnmark{}
	\ifem@il
	\@footnotetext{\the\@toksemail}
	\fi
	\ifsezion@
	\@footnotetext{\the\@tokssezione}
	\else
	\ClassError{congrumi11}{Manca il comando \noexpand\sezione}{Occorre 
	indicare la sezione in cui viene presentata la comunicazione mediante 
	il comando \noexpand\sezione{numero sezione}}
	\fi}
% bibliografia
\newenvironment{bibliografia}
{\sloppy\par\medskip\noindent\textbf{Bibliografia}\list{\labelenumi}{%
	\def\labelenumi{[\theenumi]}
	\usecounter{enumi}
	\itemindent0pt
	\settowidth\labelwidth{[9]}
	\leftmargin\labelwidth\advance\leftmargin\labelsep
	\itemsep3ptplus1ptminus.5pt
	\topsep4ptplus1ptminus.5pt
	\parsep0pt
	\partopsep0pt}}
{\endlist}

% disattivazione di \renewcommand \renewenvironment
\def\renewcommand{%
	\ClassError{congrumi11}{Le macro non possono essere ridefinite, quindi
	il comando \noexpand\renewcommand non puo' essere utilizzato}{}}
\def\renewenvironment{%
	\ClassError{congrumi11}{Gli ambienti non possono essere ridefiniti, quindi
	il comando \noexpand\renewenvironment non puo' essere utilizzato}{}}

% definizione di \thanks come in LaTeX originale
\def\thanks#1{\footnotemark
	\protected@xdef\@thanks{\@thanks
	\protect\footnotetext[\the\c@footnote]{#1}}}
\let\@thanks\@empty
